@@ -12,7 +12,7 @@ use std::ptr;
 
 use crate::{check_status, sys};
 
-use super::{FromNapiValue, ToNapiValue, TypeName};
+use super::{FromNapiValue, ToNapiValue, TypeName, ValidateNapiValue};
 
 /// i64 is converted to `Number`
 #[repr(transparent)]
@@ -38,6 +38,12 @@ impl TypeName for BigInt {
   }
 }
 
+impl ValidateNapiValue for BigInt {
+  fn type_of() -> Vec<crate::ValueType> {
+    vec![crate::ValueType::BigInt]
+  }
+}
+
 impl FromNapiValue for BigInt {
   unsafe fn from_napi_value(env: sys::napi_env, napi_val: sys::napi_value) -> crate::Result<Self> {
     let mut word_count = 0usize;
